==> haskell-hpack-0.35.2-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hpack
version:              0.35.2
visibility:           public
id:                   hpack-0.35.2-AEVbtQh5Rtl5SOyjMwXkX9
key:                  hpack-0.35.2-AEVbtQh5Rtl5SOyjMwXkX9
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  03c6ee48116d7e4b515231c326f484e8
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hpack-0.35.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hpack-0.35.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.2-AEVbtQh5Rtl5SOyjMwXkX9
depends:
    Cabal-3.6.3.0 Glob-0.10.2-EbzlotFZmcj3T0dHM5Iogf
    aeson-2.1.2.1-7dcOSp8IaGA80HTLJplaly base-4.16.4.0
    bifunctors-5.6-GXkge9NbTGOBMjMYCER7rO bytestring-0.11.4.0
    containers-0.6.5.1 cryptonite-0.30-4sVTsME4FC2Kuj4PQGWqjm
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2
    http-client-0.7.15-G7zVkalqm101uUqzYaPjBz
    http-client-tls-0.3.6.3-3GbYb7Aa9IR7ydBQPdRpjC
    http-types-0.12.3-5IXA4G35MTjEIDedTW2NzQ
    infer-license-0.2.0-GYvnMpq3vL6HsWyrlUhRNK pretty-1.1.3.6
    scientific-0.3.7.0-4N3HWbhhMZ4D2PBnQaMqAR text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-CSp7eswk3xw8n1zllorsNO
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4
    yaml-0.11.11.2-7OKpqdsA8Rq9u0pgC4RV2N

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.35.2-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hpack
version:              0.35.2
visibility:           public
id:                   hpack-0.35.2-GvgY0ZKiEODE8nUXUlsqwO
key:                  hpack-0.35.2-GvgY0ZKiEODE8nUXUlsqwO
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  434b8726915e7339695a0d1b2d263682
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hpack-0.35.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hpack-0.35.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.2-GvgY0ZKiEODE8nUXUlsqwO
depends:
    Cabal-3.6.3.0 Glob-0.10.2-EbzlotFZmcj3T0dHM5Iogf
    aeson-2.1.2.1-2DC8oo6JY6hDnCPVtrY9Cs base-4.16.4.0
    bifunctors-5.6-H345eq9KXM977VNs0CxcDN bytestring-0.11.4.0
    containers-0.6.5.1 cryptonite-0.30-4sVTsME4FC2Kuj4PQGWqjm
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2
    http-client-0.7.15-1rEunxZVzGx9PhfeNag7Vk
    http-client-tls-0.3.6.3-H1Gd4S816EhHsdCpWSwn77
    http-types-0.12.4-HcGM6QE1zVBGXemJAtRT5a
    infer-license-0.2.0-GYvnMpq3vL6HsWyrlUhRNK pretty-1.1.3.6
    scientific-0.3.7.0-4N3HWbhhMZ4D2PBnQaMqAR text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-2sfG1n18ekp4kj5cDOH71Y
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4
    yaml-0.11.11.2-3FstDPv1a6PDmZpKairZ08

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
